@@ -225,8 +225,11 @@ DataImpl :: xover_add (const Quark         & server,
   GroupHeaders * h (get_group_headers (group));
   h->_dirty = true;
   XOverEntry& workarea (xover_get_workarea (group));
+const bool d (subject == "filmy - jakie polecacie");
+if (d) std::cerr << LINE_ID << " references_in[" << references_in << ']' << std::endl;
   const std::string references (
     GNKSA :: remove_broken_message_ids_from_references (references_in));
+if (d) std::cerr << LINE_ID << " references [" << references << ']' << std::endl;
 
   /***
   **** Multipart Handling
@@ -306,6 +309,7 @@ DataImpl :: xover_add (const Quark         & server,
   **/
 
   if (workarea._batch_parts_size >= 10000)
+  //if (workarea._batch_parts_size >= 100) // torture test
   {
 //std::cerr << LINE_ID << " flushing changed size: " << workarea._changed_batch.size() << ", added size " << workarea._added_batch.size() << std::endl;
     on_articles_added (group, workarea._added_batch);
