@@ -1115,6 +1115,12 @@ BodyPane :: text_size_allocated (GtkWidget     * text,
 ****
 ***/
 
+namespace {
+  void clear_pointer_on_destroy_signal (GtkWidget*& w) {
+    g_signal_connect (w, "destroy", G_CALLBACK(gtk_widget_destroyed), &w);
+  }
+}
+
 BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs):
   _prefs (prefs),
   _data (data),
@@ -1195,6 +1201,15 @@ BodyPane :: BodyPane (Data& data, ArticleCache& cache, Prefs& prefs):
 
   _root = vbox;
   _prefs.add_listener (this);
+
+  clear_pointer_on_destroy_signal (_expander);
+  clear_pointer_on_destroy_signal (_terse);
+  clear_pointer_on_destroy_signal (_verbose);
+  clear_pointer_on_destroy_signal (_headers);
+  clear_pointer_on_destroy_signal (_xface);
+  clear_pointer_on_destroy_signal (_root);
+  clear_pointer_on_destroy_signal (_text);
+
   gtk_widget_show_all (_root);
 }
 
