@@ -846,6 +846,12 @@ GroupPane :: on_selection_changed (GtkTreeSelection * sel, gpointer pane_gpointe
   self->_action_manager.sensitize_action ("show-group-preferences-dialog", is_group(group));
 }
 
+namespace {
+  void clear_pointer_on_destroy_signal (GtkWidget*& w) {
+    g_signal_connect (w, "destroy", G_CALLBACK(gtk_widget_destroyed), &w);
+  }
+}
+
 GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs):
   _prefs (prefs),
   _data (data),
@@ -890,7 +896,8 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs)
 
   gtk_container_add (GTK_CONTAINER(scroll), _tree_view);
 
-   GtkCellRenderer * text_renderer = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, NULL));
+   const int xpad (prefs.get_int ("tree-view-row-margins", 1));
+   GtkCellRenderer * text_renderer = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, NULL));
 
    GtkTreeViewColumn * col = gtk_tree_view_column_new ();
    gtk_tree_view_column_set_sizing (col ,GTK_TREE_VIEW_COLUMN_FIXED);
@@ -907,6 +914,9 @@ GroupPane :: GroupPane (ActionManager& action_manager, Data& data, Prefs& prefs)
   _prefs.add_listener (this);
 
   refresh_font ();
+
+  clear_pointer_on_destroy_signal (_root);
+  clear_pointer_on_destroy_signal (_tree_view);
 }
 
 GroupPane :: ~GroupPane ()
