@@ -177,7 +177,7 @@ GUI :: GUI (Data& data, Queue& queue, ArticleCache& cache, Prefs& prefs, GroupPr
 
   //_group_pane = new GroupPane (*this, data, _prefs);
   _group_pane = new GroupPane (*this, data, _prefs);
-  _header_pane = new HeaderPane (*this, data, _cache, _prefs);
+  _header_pane = new HeaderPane (*this, data, _queue, _cache, _prefs);
   _body_pane = new BodyPane (data, _cache, _prefs);
 
   std::string path = "/ui/main-window-toolbar";
@@ -326,17 +326,21 @@ GUI :: ~GUI ()
   Log::get().remove_listener (this);
   g_source_remove (upkeep_tag);
 
-  gtk_widget_unref (_body_pane->root());
-  gtk_widget_unref (_header_pane->root());
-  gtk_widget_unref (_group_pane->root());
-  gtk_widget_unref (_error_image);
-  gtk_widget_unref (_info_image);
+  std::set<GtkWidget*> unref;
+  unref.insert (_body_pane->root());
+  unref.insert (_header_pane->root());
+  unref.insert (_group_pane->root());
+  unref.insert (_error_image);
+  unref.insert (_info_image);
 
   delete _header_pane;
   delete _group_pane;
   delete _body_pane;
   for (size_t i(0), size(_views.size()); i!=size; ++i)
     delete _views[i];
+
+  foreach (std::set<GtkWidget*>, unref, it)
+    gtk_widget_unref (*it);
 }
 
 /***
@@ -714,7 +718,7 @@ void GUI :: do_clear_body_pane ()
 void GUI :: do_read_more ()
 {
   if (!_body_pane->read_more ())
-    activate_action ("read-next-unread-article");
+    activate_action ("read-next-article");
 }
 void GUI :: do_read_less ()
 {
@@ -815,7 +819,7 @@ void GUI :: set_selected_thread_score (int score)
   Scorefile::AddItem items[2];
   items[0].on = true;
   items[0].negate = false;
-  items[0].key = "Message-Id";
+  items[0].key = "Message-ID";
   items[0].value = TextMatch::create_regex (tok, TextMatch::IS);
   items[1].on = true;
   items[1].negate = false;
@@ -871,14 +875,14 @@ void GUI :: do_delete_article ()
 }
 void GUI :: do_mark_article_read ()
 {
-  const std::set<const Article*> article_set (_header_pane->get_full_selection ());
+  const std::set<const Article*> article_set (_header_pane->get_nested_selection ());
   const std::vector<const Article*> tmp (article_set.begin(), article_set.end());
   _data.mark_read ((const Article**)&tmp.front(), tmp.size());
 }
 
 void GUI :: do_mark_article_unread ()
 {
-  const std::set<const Article*> article_set (_header_pane->get_full_selection ());
+  const std::set<const Article*> article_set (_header_pane->get_nested_selection ());
   const std::vector<const Article*> tmp (article_set.begin(), article_set.end());
   _data.mark_read ((const Article**)&tmp.front(), tmp.size(), false);
 }
@@ -1133,12 +1137,6 @@ void GUI :: do_quit ()
 }
 void GUI :: do_read_selected_group ()
 {
-  if (_prefs.get_flag ("mark-group-read-when-leaving-group", false)) {
-    const Quark old_group (_header_pane->get_group());
-    if (!old_group.empty())
-      _data.mark_group_read (old_group);
-  }
-
   const Quark group (_group_pane->get_selection ());
 
   // update the titlebar
