@@ -28,34 +28,6 @@
 #define IS_SORTED(tree) \
   (tree->sort_column_id != GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID)
 
-struct PanTreeStore :: Node
-{
-  /** Pointer to the parent node. */
-  Node * parent;
-
-  int n_children () const { return (int) children.size(); }
-
-  /** Pointers to the child nodes. */
-  std::vector<Node*> children;
-
-  Node* nth_child (int n) {
-    Node * ret (0);
-    if (0<=n && n<(int)children.size())
-      ret = children[n];
-    return ret;
-  }
-
-  /** This node's index in it's parent's `children' vector.
-      Used for fast building of GtkTreePath. */
-  int child_index;
-
-  /** This row's values, created by the client and given to us via insert_n() */
-  Row * values;
-
-  Node(): parent(0), child_index(-1), values(0) {}
-  ~Node() { }
-};
-
 /***
 ****  Row Helper Functions
 ***/
@@ -100,44 +72,41 @@ PanTreeStore :: Row :: set_value_static_string (GValue * setme, const char * val
 ****  Low-level utilities
 ***/
 
-PanTreeStore :: Node*
-PanTreeStore :: get_node (GtkTreeIter * iter)
+void
+PanTreeStore :: get_iter (Row * row, GtkTreeIter * setme)
 {
-  g_assert (iter);
-  g_assert (iter->stamp == stamp);
-  Node * n = static_cast<Node*>(iter->user_data);
-  g_assert (n);
-  return n;
+  g_assert (setme);
+  g_assert (row);
+  set_iter (setme, row);
 }
 
+
 PanTreeStore :: Row*
 PanTreeStore :: get_row (GtkTreeIter * iter)
-{
-  return get_node(iter)->values;
-}
-
-const PanTreeStore :: Node*
-PanTreeStore :: get_node (const GtkTreeIter * iter) const
 {
   g_assert (iter);
   g_assert (iter->stamp == stamp);
-  const Node * n = static_cast<const Node*>(iter->user_data);
-  g_assert (n);
-  return n;
+  Row * row (static_cast<Row*>(iter->user_data));
+  g_assert (row);
+  return row;
 }
 
 const PanTreeStore :: Row*
-PanTreeStore :: get_row (GtkTreeIter * iter) const
+PanTreeStore :: get_row (const GtkTreeIter * iter) const
 {
-  return get_node(iter)->values;
+  g_assert (iter);
+  g_assert (iter->stamp == stamp);
+  const Row * row (static_cast<const Row*>(iter->user_data));
+  g_assert (row);
+  return row;
 }
 
 void
 PanTreeStore :: set_iter (GtkTreeIter * iter,
-                          Node        * node)
+                          Row         * row)
 {
   iter->stamp = stamp;
-  iter->user_data = node;
+  iter->user_data = row;
   iter->user_data2 = 0;
   iter->user_data3 = 0;
 }
@@ -187,18 +156,18 @@ PanTreeStore :: model_get_iter (GtkTreeModel * model,
   g_return_val_if_fail (store, false);
   g_return_val_if_fail (path, false);
 
-  // find the Node that corresponds to this path.
-  PanTreeStore::Node * node (store->root);
+  // find the Row that corresponds to this path.
+  PanTreeStore::Row * row (store->root);
   const int depth (gtk_tree_path_get_depth (path));
   const int * indices = gtk_tree_path_get_indices (path);
   for (int i=0; i<depth; ++i) {
-    node = node->nth_child (*indices++);
-    if (!node)
+    row = row->nth_child (*indices++);
+    if (!row)
       return false;
   }
 
-  // build an iter from that node.
-  store->set_iter (iter, node);
+  // build an iter from that row.
+  store->set_iter (iter, row);
   return true;
 }
 
@@ -224,7 +193,7 @@ PanTreeStore :: model_get_value (GtkTreeModel * model,
   g_assert (iter->stamp == store->stamp);
   g_assert (0<=column && column<store->n_columns);
 
-  store->get_node(iter)->values->get_value (column, dest_value);
+  store->get_row(iter)->get_value (column, dest_value);
 }
 
 gboolean
@@ -236,15 +205,15 @@ PanTreeStore :: model_iter_next (GtkTreeModel * model,
   g_return_val_if_fail (iter, false);
   g_return_val_if_fail (iter->stamp == tree->stamp, false);
 
-  PanTreeStore::Node * node (tree->get_node (iter));
-  node = node->parent->nth_child (node->child_index + 1);
+  Row * row (tree->get_row (iter));
+  row = row->parent->nth_child (row->child_index + 1);
 
-  if (node)
-    tree->set_iter (iter, node);
+  if (row)
+    tree->set_iter (iter, row);
   else
     invalidate_iter (iter);
 
-  return node != 0;
+  return row != 0;
 }
 
 gboolean
@@ -263,8 +232,8 @@ PanTreeStore :: model_iter_n_children (GtkTreeModel * model,
   g_return_val_if_fail (tree, 0);
   g_return_val_if_fail (!iter || iter->stamp == tree->stamp, 0);
 
-  const PanTreeStore::Node * node (iter ? tree->get_node(iter) : tree->root);
-  return node->n_children();
+  const Row * row (iter ? tree->get_row(iter) : tree->root);
+  return row->n_children();
 }
 
 gboolean
@@ -285,15 +254,15 @@ PanTreeStore :: model_iter_nth_child (GtkTreeModel * model,
   g_return_val_if_fail (iter, false);
   g_return_val_if_fail (!parent || parent->stamp == tree->stamp, false);
 
-  PanTreeStore::Node * node (parent ? tree->get_node(parent) : tree->root);
-  node = node->nth_child (n);
+  Row * row (parent ? tree->get_row(parent) : tree->root);
+  row = row->nth_child (n);
 
-  if (node)
-    tree->set_iter (iter, node);
+  if (row)
+    tree->set_iter (iter, row);
   else
     invalidate_iter (iter);
 
-  return node != 0;
+  return row != 0;
 }
 
 gboolean
@@ -308,23 +277,31 @@ PanTreeStore :: model_iter_parent (GtkTreeModel * model,
 ******
 *****/
 
+GtkTreePath*
+PanTreeStore :: get_path (const Row * row) const
+{
+  g_return_val_if_fail (row, false);
+
+  std::vector<int> indices;
+  while (row && row!=root) {
+    indices.push_back (row->child_index);
+    row = row->parent;
+  }
+
+  GtkTreePath * path = gtk_tree_path_new ();
+  for (std::vector<int>::const_reverse_iterator it(indices.rbegin()), end(indices.rend()); it!=end; ++it)
+    gtk_tree_path_append_index (path, *it);
+
+  return path;
+}
+
 GtkTreePath*
 PanTreeStore :: get_path (GtkTreeIter  * iter)
 {
   g_return_val_if_fail (iter, false);
   g_return_val_if_fail (iter->stamp == stamp, false);
 
-  GtkTreePath * path = gtk_tree_path_new ();
-  PanTreeStore::Node * node (get_node (iter));
-  std::vector<int> indices;
-  while (node && node!=root) {
-    indices.push_back (node->child_index);
-    node = node->parent;
-  }
-  for (std::vector<int>::const_reverse_iterator it(indices.rbegin()), end(indices.rend()); it!=end; ++it)
-    gtk_tree_path_append_index (path, *it);
-
-  return path;
+  return get_path (get_row (iter));
 }
 
 bool
@@ -335,10 +312,10 @@ PanTreeStore :: get_parent (GtkTreeIter * iter,
   g_return_val_if_fail (iter, false);
   g_return_val_if_fail (child->stamp == stamp, false);
 
-  const PanTreeStore::Node * node = get_node (child);
-  const bool has_parent = node->parent != root;
+  const Row * row (get_row (child));
+  const bool has_parent = row->parent != root;
   if (has_parent)
-    set_iter (iter, node->parent);
+    set_iter (iter, row->parent);
   else
     invalidate_iter (iter);
   return has_parent;
@@ -347,7 +324,7 @@ PanTreeStore :: get_parent (GtkTreeIter * iter,
 bool
 PanTreeStore :: is_root (const GtkTreeIter* iter) const
 {
-  return iter && get_node(iter)->parent==root;
+  return iter && get_row(iter)->parent==root;
 }
 
 
@@ -389,7 +366,7 @@ struct
 PanTreeStore :: SortTuple
 {
   int offset;
-  PanTreeStore::Node * node;
+  Row * row;
   GtkTreeIter iter;
 };
 
@@ -421,14 +398,14 @@ PanTreeStore :: tuple_compare_func (gconstpointer a_gpointer,
     val = -val;
 
   if (!val) // inplace sort
-    val = help->store->get_node(const_cast<GtkTreeIter*>(&a->iter))->child_index - 
-          help->store->get_node(const_cast<GtkTreeIter*>(&b->iter))->child_index;
+    val = help->store->get_row(&a->iter)->child_index - 
+          help->store->get_row(&b->iter)->child_index;
 
   return val;
 }
 
 void
-PanTreeStore :: renumber_children (Node * parent,
+PanTreeStore :: renumber_children (Row * parent,
                                    int child_lo,
                                    int child_hi)
 {
@@ -440,7 +417,7 @@ PanTreeStore :: renumber_children (Node * parent,
   g_assert (child_lo <= child_hi);
   g_assert (child_hi <= n_children);
 
-  Node ** it = &parent->children[child_lo];
+  Row ** it = &parent->children[child_lo];
   for (int i=child_lo; i!=child_hi; ++i, ++it) {
     (*it)->child_index = i;
     (*it)->parent = parent;
@@ -459,7 +436,7 @@ PanTreeStore :: renumber_children (Node * parent,
 
 void
 PanTreeStore :: sort_helper (SortInfo  & sort_info,
-                             Node      * parent,
+                             Row       * parent,
                              bool        recurse)
 {
   g_assert (parent);
@@ -473,8 +450,8 @@ PanTreeStore :: sort_helper (SortInfo  & sort_info,
   for (int i=0; i<n; ++i) {
     SortTuple& tuple = sort_array[i];
     tuple.offset = i;
-    tuple.node = parent->children[i];
-    set_iter (&tuple.iter, tuple.node);
+    tuple.row = parent->children[i];
+    set_iter (&tuple.iter, tuple.row);
   }
 
   // sort 'em...
@@ -486,7 +463,7 @@ PanTreeStore :: sort_helper (SortInfo  & sort_info,
 
   // update the child indices...
   for (int i=0; i<n; ++i) {
-    Node * child = sort_array[i].node;
+    Row * child = sort_array[i].row;
     child->child_index = i;
     parent->children[i] = child;
     g_assert (child->parent == parent);
@@ -518,7 +495,7 @@ PanTreeStore :: sort_helper (SortInfo  & sort_info,
   delete [] sort_array;
 
   for (int i=0; recurse && i<n; ++i) {
-    Node * child = parent->children[i];
+    Row * child = parent->children[i];
     sort_helper (sort_info, child, recurse);
   }
 }
@@ -598,14 +575,13 @@ namespace
 }
 
 struct
-PanTreeStore :: FreeNodeWalker: public PanTreeStore::WalkFunctor
+PanTreeStore :: FreeRowWalker: public PanTreeStore::WalkFunctor
 {
   PanTreeStore * store;
-  FreeNodeWalker (PanTreeStore *t): store(t) {}
-  virtual ~FreeNodeWalker () {}
-  virtual bool operator()(PanTreeStore *tree, PanTreeStore::Row *row, GtkTreeIter*it, GtkTreePath *p) {
-    delete row;
-    delete store->get_node(it);
+  FreeRowWalker (PanTreeStore *t): store(t) {}
+  virtual ~FreeRowWalker () {}
+  virtual bool operator()(PanTreeStore *s, Row *r, GtkTreeIter*it, GtkTreePath *p) {
+    delete r;
     return true; // keep marching
   }
 };
@@ -615,7 +591,7 @@ PanTreeStore :: pan_tree_finalize (GObject *object)
 {
   // erase the remaining nodes
   PanTreeStore * store = PAN_TREE_STORE(object);
-  FreeNodeWalker walk (store);
+  FreeRowWalker walk (store);
   store->postfix_walk (walk);
   delete store->root;
    
@@ -663,12 +639,19 @@ PanTreeStore :: pan_tree_sortable_init (GtkTreeSortableIface *iface)
   iface->has_default_sort_func = sortable_has_default_sort_func;
 }
 
+namespace
+{
+  class RootRow: public PanTreeStore::Row {
+    virtual void get_value (int column, GValue * setme) { /* unused */ }
+  };
+}
+
 void
 PanTreeStore :: pan_tree_init (PanTreeStore * tree)
 {
   tree->stamp = g_random_int();
   tree->n_columns = 0;
-  tree->root = new PanTreeStore::Node ();
+  tree->root = new RootRow ();
   tree->column_types = new std::vector<GType>();
   tree->sort_paused = 0;
   tree->sort_info = new std::map<int,PanTreeStore::SortInfo>();
@@ -676,15 +659,6 @@ PanTreeStore :: pan_tree_init (PanTreeStore * tree)
   tree->order = GTK_SORT_ASCENDING;
 }
 
-void
-PanTreeStore :: alloc_nodes (size_t               n_rows,
-                             std::vector<Node*> & setme)
-{
-  setme.resize (n_rows);
-  for (std::vector<Node*>::iterator it(setme.begin()), end(setme.end()); it!=end; ++it)
-    *it = new Node ();
-}
-
 /***
 ****
 ***/
@@ -743,6 +717,14 @@ PanTreeStore :: new_tree (int n_columns, ...)
 ****
 ***/
 
+void
+PanTreeStore :: row_changed (Row * row)
+{
+  GtkTreeIter iter;
+  get_iter (row, &iter);
+  row_changed (&iter);
+}
+
 void
 PanTreeStore :: row_changed (GtkTreeIter * iter)
 {
@@ -783,47 +765,41 @@ pan_tree_store_insert_n  (PanTreeStore                    * tree,
 void
 PanTreeStore :: insert_n (GtkTreeIter                     * iter,
                           GtkTreeIter                     * parent_it,
-                          rows_t                          & rows,
+                          rows_t                          & new_children,
                           int                               position)
 {
-  g_return_if_fail (!rows.empty());
+  g_return_if_fail (!new_children.empty());
   g_return_if_fail (position >= 0);
 
-  // allocate the nodes
-  std::vector<PanTreeStore::Node*> new_children;
-  const size_t n_rows (rows.size());
-  alloc_nodes (n_rows, new_children);
-  for (size_t i(0), count(n_rows); i!=count; ++i)
-    new_children[i]->values = rows[i];
-
-  // insert the nodes
-  PanTreeStore::Node * parent_node (parent_it ? get_node (parent_it) : root);
-  const int old_size (parent_node->n_children());
+  // insert the rows
+  const size_t n_rows (new_children.size());
+  Row * parent_row (parent_it ? get_row (parent_it) : root);
+  const int old_size (parent_row->n_children());
   position = std::min (position, old_size);
-  parent_node->children.insert (parent_node->children.begin()+position,
-                                new_children.begin(),
-                                new_children.end());
-  renumber_children (parent_node, position);
+  parent_row->children.insert (parent_row->children.begin()+position,
+                               new_children.begin(),
+                               new_children.end());
+  renumber_children (parent_row, position);
 
   // set the return iter
   GtkTreeIter walk;
-  set_iter (&walk, parent_node->children[position]);
+  set_iter (&walk, parent_row->children[position]);
   if (iter)
     *iter = walk;
 
   // emit the 'row inserted' signals
   GtkTreePath * path = get_path (&walk);
   GtkTreeModel * model = GTK_TREE_MODEL(this);
-  PanTreeStore::Node** it = &parent_node->children[position];
+  Row ** it = &parent_row->children[position];
   for (size_t i=0; i<n_rows; ++i) {
-    PanTreeStore::Node * node (*it++);
-    set_iter (&walk, node);
+    Row * row (*it++);
+    set_iter (&walk, row);
     gtk_tree_model_row_inserted (model, path, &walk);
     gtk_tree_path_next (path);
   }
 
   // maybe emit the 'row has childed' signal
-  if (!old_size && parent_node!=root) {
+  if (!old_size && parent_row!=root) {
     gtk_tree_path_up (path);
     gtk_tree_model_row_has_child_toggled (model, path, parent_it);
   }
@@ -868,8 +844,7 @@ struct PanTreeStore::ReparentWalker: public PanTreeStore::WalkFunctor
   virtual bool operator()(PanTreeStore *store, Row* row,
                           GtkTreeIter *iter, GtkTreePath *path)
   {
-    Node * node (store->get_node (iter));
-    const int n_children (node->n_children());
+    const int n_children (row->n_children());
 
     if (n_children)
     {
@@ -877,7 +852,7 @@ struct PanTreeStore::ReparentWalker: public PanTreeStore::WalkFunctor
       GtkTreePath * cpath (gtk_tree_path_copy (path));
       gtk_tree_path_down (cpath);
       for (int i=0; i<n_children; ++i) {
-        Node * child (node->nth_child (i));
+        Row * child (row->nth_child (i));
         GtkTreeIter citer;
         store->set_iter (&citer, child);
         gtk_tree_model_row_inserted (model, cpath, &citer);
@@ -894,21 +869,21 @@ struct PanTreeStore::ReparentWalker: public PanTreeStore::WalkFunctor
 };
 
 void
-PanTreeStore :: reparent (GtkTreeIter    * parent_iter,
-                          GtkTreeIter    * iter,
+PanTreeStore :: reparent (Row            * new_parent,
+                          Row            * row,
                           int              position)
 {
-  g_return_if_fail (iter != 0);
+  g_return_if_fail (row != 0);
 
   GtkTreeModel * model (GTK_TREE_MODEL(this));
 
-  Node * node (get_node (iter));
-  Node * old_parent (node->parent);
-  Node * new_parent (parent_iter ? get_node(parent_iter) : root);
+  Row * old_parent (row->parent);
+  if (!new_parent)
+    new_parent = root;
   const int new_parent_old_n_children (new_parent->n_children());
 
   // remove our subtree's toplevel from its old parent
-  remove_siblings (&node, 1, false);
+  remove_siblings (&row, 1, false);
 
   // if this was the old parent's last child, fire a has-child-toggled event
   if (!old_parent->n_children()) {
@@ -919,44 +894,49 @@ PanTreeStore :: reparent (GtkTreeIter    * parent_iter,
     gtk_tree_path_free (path);
   }
 
-  // add the subtree's toplevel to its new parent node
+  // add the subtree's toplevel to its new parent row
   position = std::min (position, new_parent_old_n_children);
-  new_parent->children.insert (new_parent->children.begin()+position, node);
+  new_parent->children.insert (new_parent->children.begin()+position, row);
   renumber_children (new_parent, position);
 
   // emit a row-inserted for iter
-  GtkTreePath * path (get_path (iter));
-  gtk_tree_model_row_inserted (model, path, iter);
+  GtkTreeIter iter;
+  get_iter (row, &iter);
+  GtkTreePath * path (get_path (&iter));
+  gtk_tree_model_row_inserted (model, path, &iter);
   gtk_tree_path_free (path);
 
   // this emits all the row-inserted and has-child-toggled signals EXCEPT
   // for iter's row-inserted (above) and parent-iter's has-child-toggled (below).
   // It's kind of kludgy but gets all the signals emitted in the right sequence.
   ReparentWalker walk (this);
-  prefix_walk (walk, iter, true);
+  prefix_walk (walk, &iter, true);
 
   // if this was the new parent's first child, fire a has-child-toggled event
   if (!new_parent_old_n_children) {
-    GtkTreePath * path (get_path (parent_iter));
-    gtk_tree_model_row_has_child_toggled (model, path, parent_iter);
+    GtkTreePath * path (get_path (new_parent));
+    GtkTreeIter new_parent_iter;
+    get_iter (new_parent, &new_parent_iter);
+    gtk_tree_model_row_has_child_toggled (model, path, &new_parent_iter);
     gtk_tree_path_free (path);
   }
 }
 
+
 /***
 ****
 ***/
 
-struct PanTreeStore :: NodeCompare
+struct PanTreeStore :: RowCompare
 {
-  Node * root;
-  NodeCompare (Node * r): root(r) {}
+  Row * root;
+  RowCompare (Row * r): root(r) {}
 
-  int depth (const Node * node) const {
+  int depth (const Row * row) const {
     int depth (0);
-    while (node->parent != root) {
+    while (row->parent != root) {
       ++depth;
-      node = node->parent;
+      row = row->parent;
     }
     return depth;
   }
@@ -966,7 +946,7 @@ struct PanTreeStore :: NodeCompare
   // we group by parent so to get groups of siblings for remove_siblings().
   // we sort by child_index so the first siblings removed in
   // remove_siblings() don't invalidate the tree path it uses.
-  bool operator() (const Node* a, const Node* b) const {
+  bool operator() (const Row* a, const Row* b) const {
     // deepest first
     const int a_depth (depth (a));
     const int b_depth (depth (b));
@@ -987,16 +967,16 @@ PanTreeStore :: remove (GtkTreeIter * iters,
   g_return_if_fail (iters);
   g_return_if_fail (n_iters);
 
-  Node ** nodes = new Node* [n_iters];
+  Row ** rows = new Row* [n_iters];
   for (size_t i=0; i<n_iters; ++i)
-    nodes[i] = get_node (iters+i);
+    rows[i] = get_row (iters+i);
 
-  NodeCompare compare (root);
-  std::sort (nodes, nodes+n_iters, compare);
+  RowCompare compare (root);
+  std::sort (rows, rows+n_iters, compare);
 
-  Node * parent (0);
-  Node ** children (0);
-  for (Node **nit=nodes, **nend=nodes+n_iters; nit!=nend; ++nit) {
+  Row * parent (0);
+  Row ** children (0);
+  for (Row **nit=rows, **nend=rows+n_iters; nit!=nend; ++nit) {
     if (parent && ((*nit)->parent != parent)) {
       remove_siblings (children, nit-children, true);
       parent = 0;
@@ -1008,21 +988,21 @@ PanTreeStore :: remove (GtkTreeIter * iters,
     }
   }
   if (parent) {
-    size_t n = (nodes + n_iters) - children;
+    size_t n = (rows + n_iters) - children;
     remove_siblings (children, n, true);
   }
 
-  delete [] nodes;
+  delete [] rows;
 }
 
 struct PanTreeStore::ClearWalker: public PanTreeStore::WalkFunctor
 {
   virtual ~ClearWalker () {}
 
-  void clear_children (PanTreeStore* store, Node * node)
+  void clear_children (PanTreeStore* store, Row * row)
   {
-    if (node->n_children()) {
-      std::vector<Node*> children = node->children;
+    if (row->n_children()) {
+      std::vector<Row*> children (row->children);
       std::reverse (children.begin(), children.end());
       store->remove_siblings (&children.front(), children.size(), true);
     }
@@ -1032,7 +1012,7 @@ struct PanTreeStore::ClearWalker: public PanTreeStore::WalkFunctor
                           PanTreeStore::Row* row,
                           GtkTreeIter* iter, GtkTreePath* path)
   {
-    clear_children (store, store->get_node(iter));
+    clear_children (store, store->get_row(iter));
     return true;
   }
 };
@@ -1049,15 +1029,15 @@ PanTreeStore :: clear ()
 // note that the siblings passed in here must
 // be sorted from highest child index to lowest child index
 void
-PanTreeStore :: remove_siblings (Node ** siblings,
-                                 size_t n_siblings,
-                                 bool free_memory)
+PanTreeStore :: remove_siblings (Row     ** siblings,
+                                 size_t     n_siblings,
+                                 bool      free_memory)
 {
   // entry assertions
   g_assert (siblings);
   g_assert (n_siblings);
-  Node * parent = siblings[0]->parent;
-  for (Node **nit(siblings), **nend(nit+n_siblings); nit!=nend; ++nit) {
+  Row * parent = siblings[0]->parent;
+  for (Row **nit(siblings), **nend(nit+n_siblings); nit!=nend; ++nit) {
     g_assert ((*nit)->parent == parent); // all are siblings
     g_assert (nit==siblings || ((*nit)->child_index < nit[-1]->child_index)); // sorted from high to low child index
   }
@@ -1072,23 +1052,23 @@ PanTreeStore :: remove_siblings (Node ** siblings,
   last_path_index += gtk_tree_path_get_depth(path)-1;
 
   // walk through all the siblings and unthread them.
-  for (Node** nit(siblings), **nend(siblings+n_siblings); nit!=nend; ++nit)
+  for (Row** nit(siblings), **nend(siblings+n_siblings); nit!=nend; ++nit)
   {
-    Node * node (*nit);
-    g_assert (node->parent);
-    g_assert (node->parent == parent);
+    Row * row (*nit);
+    g_assert (row->parent);
+    g_assert (row->parent == parent);
 
-    // unthread the node
-    const int pos = node->child_index;
+    // unthread the row
+    const int pos = row->child_index;
     parent->children.erase (parent->children.begin() + pos);
 
     // let the world know the row was removed
-    *last_path_index = node->child_index;
+    *last_path_index = row->child_index;
     gtk_tree_model_row_deleted (model, path);
 
-    // free `node' and all its descendants
+    // free `row' and all its descendants
     if (free_memory) {
-      FreeNodeWalker walk (this);
+      FreeRowWalker walk (this);
       GtkTreeIter iter;
       set_iter (&iter, *nit);
       postfix_walk (walk, &iter);
@@ -1115,26 +1095,26 @@ PanTreeStore :: remove_siblings (Node ** siblings,
 
 bool
 PanTreeStore :: walk_helper (int           walk_mode,
-                             Node        * node,
+                             Row         * row,
                              GtkTreePath * path,
                              WalkFunctor & walker)
 {
-  g_assert (node);
+  g_assert (row);
   g_assert (walk_mode==WALK_PREFIX || walk_mode==WALK_POSTFIX);
 
   bool more (true);
 
   GtkTreeIter iter;
-  set_iter (&iter, node);
+  set_iter (&iter, row);
 
-  if (more && node!=root && walk_mode==WALK_PREFIX)
-    more = walker (this, node->values, &iter, path);
+  if (more && row!=root && walk_mode==WALK_PREFIX)
+    more = walker (this, row, &iter, path);
 
-  const size_t n_children (node->n_children());
+  const size_t n_children (row->n_children());
   if (more && n_children) {
     if (path)
       gtk_tree_path_append_index (path, 0);
-    for (Node ** it(&node->children.front()),
+    for (Row ** it(&row->children.front()),
               ** end(it+n_children); more && it!=end; ++it) {
       more = walk_helper (walk_mode, *it, path, walker);
       if (path)
@@ -1144,8 +1124,8 @@ PanTreeStore :: walk_helper (int           walk_mode,
       gtk_tree_path_up (path);
   }
 
-  if (more && node!=root && walk_mode==WALK_POSTFIX)
-    more = walker (this, node->values, &iter, path);
+  if (more && row!=root && walk_mode==WALK_POSTFIX)
+    more = walker (this, row, &iter, path);
 
   return more;
 }
@@ -1160,8 +1140,8 @@ PanTreeStore :: walk (int             walk_mode,
   if (need_path)
     path = top ? get_path(top) : gtk_tree_path_new();
 
-  PanTreeStore::Node * node (top ? get_node(top) : root);
-  walk_helper (walk_mode, node, path, walker);
+  Row * row (top ? get_row(top) : root);
+  walk_helper (walk_mode, row, path, walker);
   gtk_tree_path_free (path);
 }
 
