@@ -56,8 +56,8 @@ struct PanTreeStoreClass
  *     This helps lower memory use by having a single Row structure
  *     rather than an array of GValues.  On an x86 architecture,
  *     sizeof(int)==4 and sizeof(GValue)==20.  (Plus we avoid
- *     GtkTreeStore's extra hit of using a linked list,
- *     so take off another sizeof(gpointer) + sizeof(GList) per cell.)
+ *     GtkTreeStore's extra hit of using linked lists to join the
+ *     cells in a row,
  *
  *  2. Population before insertion is also much faster because
  *     there are no extra calls to tree_store_set_value(), no GObject
@@ -102,6 +102,14 @@ struct PanTreeStore
 
     static GType get_type ();
 
+
+  private:
+
+    class ClearWalker;
+    class FreeRowWalker;
+    class ReparentWalker;
+    class RowCompare;
+
   public:
 
     /**
@@ -129,21 +137,53 @@ struct PanTreeStore
         void set_value_int           (GValue * setme, int);
         void set_value_string        (GValue * setme, const char *);
         void set_value_static_string (GValue * setme, const char *);
+
+      protected:
+        Row (): parent(0), child_index(-1) {}
+
+      private:
+        friend class PanTreeStore;
+        friend class ClearWalker;
+        friend class FreeRowWalker;
+        friend class ReparentWalker;
+        friend class RowCompare;
+
+        Row * parent;
+        std::vector<Row*> children;
+        int child_index;
+
+      private:
+        int n_children () const {
+          return (int) children.size();
+        }
+        Row * nth_child (int n) {
+          Row * ret (0);
+          if (0<=n && n<(int)children.size())
+            ret = children[n];
+          return ret;
+        }
     };
 
-    /** Client code _must_ call this when the contents of a row change. */
+    /** Client code _must_ call row_changed() when a row changes. */
     void row_changed (GtkTreeIter * iter);
+    /** Client code _must_ call row_changed() when a row changes. */
+    void row_changed (Row * row);
+
+    void get_iter (Row*, GtkTreeIter* setme);
 
     /** Get the Row pointed to by the GtkTreeIter. */
     Row* get_row (GtkTreeIter* iter);
 
     /** Get the Row pointed to by the GtkTreeIter. */
-    const Row* get_row (GtkTreeIter* iter) const;
+    const Row* get_row (const GtkTreeIter* iter) const;
 
     /** Build a GtkTreePath corresponding to the GtkTreeIter.
         This is equivalent to gtk_tree_model_get_path(iter). */
     GtkTreePath* get_path (GtkTreeIter* iter);
 
+    /** Build a GtkTreePath corresponding to the Row */
+    GtkTreePath* get_path (const Row* row) const;
+
   public:
 
     /**
@@ -166,8 +206,8 @@ struct PanTreeStore
                    size_t           n_iters);
 
     /** Move a row to a new parent. */
-    void reparent (GtkTreeIter    * parent_or_null_for_root,
-                   GtkTreeIter    * iter,
+    void reparent (Row            * parent_or_null_for_root,
+                   Row            * child,
                    int              pos = INT_MAX);
 
   public:
@@ -267,30 +307,17 @@ struct PanTreeStore
 
   private:
 
-    struct Node;
-
-    void set_iter (GtkTreeIter*, Node*);
+    void set_iter (GtkTreeIter*, Row*);
 
     static void invalidate_iter (GtkTreeIter*);
 
-    Node* get_node (GtkTreeIter * iter);
-
-    const Node* get_node (const GtkTreeIter * iter) const;
-
   private:
 
-    class ClearWalker;
-    class FreeNodeWalker;
-    class ReparentWalker;
-    class NodeCompare;
-
-  private:
-
-    void remove_siblings (Node ** siblings,
+    void remove_siblings (Row ** siblings,
                           size_t  n_siblings,
                           bool    free_memory);
 
-    void renumber_children (Node * parent,
+    void renumber_children (Row * parent,
                             int child_lo = 0,
                             int child_hi = INT_MAX);
 
@@ -304,7 +331,7 @@ struct PanTreeStore
                bool            need_path);
 
     bool walk_helper (int             walk_mode,
-                      Node          * top_node,
+                      Row           * top_row,
                       GtkTreePath   * top_path_or_null,
                       WalkFunctor   & walk_functor);
   private:
@@ -325,7 +352,7 @@ struct PanTreeStore
     /** The root node,  This is for implementation only;
         it's invisible to the outside world and you can't
         get a GtkTreeIter or GtkTreePath to it. */
-    Node * root;
+    Row * root;
 
   private: // gobject
     static void pan_tree_finalize (GObject *);
@@ -374,13 +401,10 @@ struct PanTreeStore
                                                     GtkDestroyNotify);
     static gboolean sortable_has_default_sort_func (GtkTreeSortable*);
  
-  private:
-    void alloc_nodes (size_t n_rows, std::vector<Node*>& setme);
-
   private:
     struct SortTuple;
     struct SortHelperData;
-    void sort_helper (SortInfo&, Node* parent, bool recurse);
+    void sort_helper (SortInfo&, Row* parent, bool recurse);
     static int tuple_compare_func (gconstpointer, gconstpointer, gpointer);
 
   private:
