@@ -477,6 +477,23 @@ PostUI :: manage_profiles ()
   apply_profile ();
 }
 
+namespace
+{
+  std::string get_text (GtkTextBuffer * buf)
+  {
+    std::string ret;
+
+    GtkTextIter start, end;
+    gtk_text_buffer_get_bounds (buf, &start, &end);
+    char * pch (gtk_text_buffer_get_text (buf, &start, &end, false));
+    if (pch)
+      ret = pch;
+    g_free (pch);
+
+    return ret;
+  }
+}
+
 void
 PostUI :: manage_editors ()
 {
@@ -514,10 +531,7 @@ PostUI :: manage_editors ()
 
   gtk_dialog_run (GTK_DIALOG (d));
 
-  GtkTextIter start, end;
-  gtk_text_buffer_get_bounds (buf, &start, &end);
-  char * text (gtk_text_buffer_get_text (buf,  &start, &end, false));
-
+  const std::string text (get_text (buf));
   commands.clear ();
   StringView token, v (text);
   while (v.pop_token (token, '\n')) {
@@ -568,14 +582,14 @@ PostUI :: wrap_body ()
   g_free (body);
 }
 
-void
-PostUI :: close_window ()
-{
-  gtk_widget_destroy (_root);
-}
-
 namespace
 {
+  gboolean delete_event_cb (GtkWidget *w, GdkEvent *e, gpointer user_data)
+  {
+    static_cast<PostUI*>(user_data)->close_window ();
+    return true; // don't invoke the default handler that destroys the widget
+  }
+
   void message_dialog_set_text (GtkMessageDialog * dialog,
                                 const char * primary,
                                 const char * secondary)
@@ -591,6 +605,35 @@ namespace
   }
 }
 
+void
+PostUI :: close_window ()
+{
+  bool destroy_flag (false);;
+
+  if (get_text (_body_buf) == _unchanged_body)
+    destroy_flag = true;
+
+  else {
+    GtkWidget * d = gtk_message_dialog_new (
+      GTK_WINDOW(_root),
+      GTK_DIALOG_DESTROY_WITH_PARENT,
+      GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, NULL);
+    message_dialog_set_text (GTK_MESSAGE_DIALOG(d),
+      _("Your changes will be lost!"),
+      _("Are you sure you want to close this window?"));
+    gtk_dialog_add_buttons (GTK_DIALOG(d),
+                            GTK_STOCK_GO_BACK, GTK_RESPONSE_NO,
+                            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                            NULL);
+    gtk_dialog_set_default_response (GTK_DIALOG(d), GTK_RESPONSE_NO);
+    destroy_flag = gtk_dialog_run (GTK_DIALOG(d)) == GTK_RESPONSE_CLOSE;
+    gtk_widget_destroy (d);
+  }
+
+  if (destroy_flag)
+    gtk_widget_destroy (_root);
+}
+
 bool
 PostUI :: check_message (const Quark& server, GMimeMessage * msg)
 {
@@ -660,7 +703,6 @@ PostUI :: on_progress_finished (Progress&, int status)
 {
   _post_task->remove_listener (this);
   gtk_widget_destroy (_post_dialog);
-  _post_dialog = 0;
   if (status == OK)
     close_window ();
   else {
@@ -669,8 +711,9 @@ PostUI :: on_progress_finished (Progress&, int status)
   }
 }
 
+namespace
+{
 #if !GTK_CHECK_VERSION(2,6,0)
-namespace {
   char* gtk_combo_box_get_active_text (GtkComboBox * combo_box) {
     char * text (0);
     GtkTreeIter  iter;
@@ -680,9 +723,14 @@ namespace {
     }
     return text;
   }
-}
 #endif
 
+  void clear_pointer_on_destroy_signal (GtkWidget*& w)
+  {
+    g_signal_connect (w, "destroy", G_CALLBACK(gtk_widget_destroyed), &w);
+  }
+}
+
 void
 PostUI :: post_now ()
 {
@@ -767,6 +815,7 @@ PostUI :: post_now ()
   gtk_box_pack_start (GTK_BOX(GTK_DIALOG(d)->vbox), w, false, false, PAD_SMALL);
   g_object_set_data_full (G_OBJECT(d), "progressbar-timeout-tag", GUINT_TO_POINTER(tag), remove_progress_tag);
   _post_dialog = d;
+  clear_pointer_on_destroy_signal (_post_dialog);
   gtk_widget_show_all (d);
   _post_task = new TaskPost (server, message);
   _post_task->add_listener (this);
@@ -986,7 +1035,7 @@ namespace
         && (name != "Newsgroups")
         && (name != "From")
         && (name != "Xref") // not editable
-        && (name != "Message-Id")
+        && (name != "Message-ID")
         && (name != "References")
         && ((name != "User-Agent") || (value != get_user_agent()))
         && (name.strstr ("Content-") != name.str)
@@ -1120,6 +1169,8 @@ PostUI :: save_draft ()
     g_free (pch);
     g_free (filename);
     g_object_unref (msg);
+
+    _unchanged_body = get_text (_body_buf);
   }
 
   gtk_widget_destroy (d);
@@ -1620,6 +1671,7 @@ PostUI :: PostUI (Data         & data,
 
   // create the window
   _root = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  g_signal_connect (_root, "delete-event", G_CALLBACK(delete_event_cb), this);
   gtk_window_set_role (GTK_WINDOW(_root), "pan-post-window");
   gtk_window_set_title (GTK_WINDOW(_root), _("Post Article"));
   g_object_set_data_full (G_OBJECT(_root), "post-ui", this, delete_post_ui);
@@ -1709,6 +1761,8 @@ PostUI :: PostUI (Data         & data,
 
   set_message (message);
 
+  _unchanged_body = get_text (_body_buf);
+
   // set focus to the first non-populated widget
   GtkWidget * grab (0);
   if (!grab) {
@@ -1724,4 +1778,10 @@ PostUI :: PostUI (Data         & data,
   if (!grab)
     grab = _body_view;
   gtk_widget_grab_focus (grab);
+
+  clear_pointer_on_destroy_signal (_root);
+  clear_pointer_on_destroy_signal (_from_combo);
+  clear_pointer_on_destroy_signal (_subject_entry);
+  clear_pointer_on_destroy_signal (_groups_entry);
+  clear_pointer_on_destroy_signal (_body_view);
 }
