@@ -398,6 +398,12 @@ TaskPane :: ~TaskPane ()
   g_source_remove (_update_timeout_tag);
 }
 
+namespace {
+  void clear_pointer_on_destroy_signal (GtkWidget*& w) {
+    g_signal_connect (w, "destroy", G_CALLBACK(gtk_widget_destroyed), &w);
+  }
+}
+
 TaskPane :: TaskPane (Queue& queue, Prefs& prefs, GtkWidget* parent): _queue(queue)
 {
   _root = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -501,4 +507,8 @@ TaskPane :: TaskPane (Queue& queue, Prefs& prefs, GtkWidget* parent): _queue(que
   gtk_window_set_resizable (GTK_WINDOW(_root), true);
   if (parent != 0)
     gtk_window_set_transient_for (GTK_WINDOW(_root), GTK_WINDOW(gtk_widget_get_toplevel(parent)));
+
+  clear_pointer_on_destroy_signal (_root);
+  clear_pointer_on_destroy_signal (_view);
+  clear_pointer_on_destroy_signal (_status_label);
 }
