@@ -372,6 +372,21 @@ Queue :: add_tasks (const tasks_t& tasks, AddMode mode)
   upkeep ();
 }
 
+bool
+Queue :: contains (const Quark& mid) const
+{
+  const Quark bodies ("BODIES");
+  const Quark save ("SAVE");
+
+  foreach_const (tasks_t, _items, it) {
+    const TaskArticle* task (dynamic_cast<const TaskArticle*>(*it));
+    if (task && task->get_article().message_id == mid)
+      return true;
+  }
+
+  return false;
+}
+
 void
 Queue :: remove_latest_task ()
 {
@@ -467,6 +482,8 @@ Queue :: check_in (NNTP * nntp, bool is_ok)
     const Quark& servername (nntp->_server);
     NNTP_Pool& pool (get_pool (servername));
     pool.check_in (nntp, is_ok);
+
+    upkeep ();
   }
 }
 
@@ -517,7 +534,6 @@ Queue :: move_bottom (const tasks_t& tasks)
     const int old_pos (index_of (task));
     TaskSet::move_bottom (old_pos);
     const int new_pos (index_of (task));
-std::cerr << LINE_ID << " moving to bottom... old_pos " << old_pos << " new_pos " << new_pos << std::endl;
     if (old_pos != new_pos)
       fire_task_moved (task, new_pos, old_pos);
   }
