@@ -192,15 +192,8 @@ TaskArticle :: use_nntp (NNTP * nntp)
   }
   else
   {
-    // if part.bytes is somehow corrupt we can crash Pan by passing
-    // too big a number to reserve(), so set an upper maximum.
-    // inn.conf(5) says 1000000 is its default maximum article size,
-    // so we'll use that.
-    const unsigned long buf_prealloc_limit (1000000);
-
     needed->nntp = nntp;
     needed->buf.clear ();
-    needed->buf.reserve (std::min (buf_prealloc_limit, needed->part.bytes));
 
     Quark group;
     unsigned long number (0ul);
@@ -264,8 +257,11 @@ TaskArticle :: on_nntp_done  (NNTP    * nntp,
 
   if (health==OK)
     _needed.erase (it);
-  else
+  else {
+    Needed::buf_t tmp;
+    it->buf.swap (tmp); // deallocates the space...
     it->nntp = 0;
+  }
 
   update_work ();
   check_in (nntp, health!=RETRY);
